type RgbColor = [number, number, number];
type HexColor = string;
type RgbRawColor = string;
/**
 * Get color from a number.
 * @param code
 * @returns color derived from hash
 */
export declare function getHexFromCode(code: number): HexColor;
/**
 * Get hash from a string.
 * @param str any string
 * @returns hash derived from string
 */
export declare function getHashFromString(str: string): number;
/**
 * Get color from string.
 * @param str any string
 */
export declare function getHexFromString(str: string): string;
/**
 * Get hex color from rgb color.
 * @param color
 */
export declare function getHexFromRgbRaw(color: RgbColor): string;
/**
 * Get hex color from rgb color.
 * @param color
 */
export declare function getHexFromRgb(color: RgbRawColor): string | undefined;
/**
 * Get rgb color from hex color.
 * @param color
 */
export declare function getRgbRawFromHex(color: HexColor): RgbColor | undefined;
/**
 * Get rgb color from hex color 'rgb(255, 255, 255)'.
 * @param hex hex color '#ffffff'
 */
export declare function getRgbFromHex(hex: HexColor): RgbRawColor | undefined;
/**
 * Convert hex to yiq colorspace and get the luma value
 * @param color
 * @returns yiq luma value
 */
export declare function getContrastYIQ(color: HexColor): number;
/**
 * Identifies if given color is valid color.
 * @param color
 */
export declare function isValidHexColor(color: string): boolean;
/**
 * Get appropriate foreground color for a given background color.
 * @param color color for background
 * @param colorOnLight color for light background
 * @param colorOnDark color for dark background
 * @returns appropriate foreground color
 */
export declare function getColorOnBgColor(color: HexColor, colorOnLight?: HexColor, colorOnDark?: HexColor): string;
/**
 * Interpolate two rgb colors.
 * @param color1
 * @param color2
 * @param factor decides where the interpolated color lies.
 * @returns interpolated rgb color
 */
export declare function interpolateRgb(color1: RgbColor, color2: RgbColor, factor?: number): RgbColor;
export {};
