import { Maybe } from './declarations';
/**
 * Does nothing
 */
export declare function noOp(): void;
/**
 * Get union of two sets.
 * @param setA
 * @param setB
 * @returns union of two sets
 */
export declare function union<T>(setA: Set<T>, setB: Set<T>): Set<T>;
/**
 * Get intersection of two sets.
 * @param setA
 * @param setB
 * @returns intersection of two sets
 */
export declare function intersection<T>(setA: Set<T>, setB: Set<T>): Set<T>;
/**
 * Get difference of two sets.
 * @param setA
 * @param setB
 * @returns difference between two sets
 */
export declare function difference<T>(setA: Set<T>, setB: Set<T>): Set<T>;
/**
 * Identifies if value is NaN.
 * @param val
 */
export declare function isNaN(val: unknown): boolean;
/**
 * Identifies if value is not defined.
 * undefined, null and NaN are not considered as defined.
 * @param val
 */
export declare function isNotDefined(val: unknown): val is undefined | null;
/**
 * Identifies if value is defined.
 * @param val
 */
export declare function isDefined<T>(val: Maybe<T>): val is T;
/**
 * Identifies if value is falsy.
 * undefined, null, NaN and false are considered as false value.
 * @param val
 * @param override list of additional values that are considered false values
 */
export declare function isFalsy(val: unknown, override?: unknown[]): val is undefined | null;
/**
 * Identifies if value is truthy.
 * @param val
 * @param override list of additional values that are considered true values
 */
export declare function isTruthy<T>(val: Maybe<T>, override?: unknown[]): val is T;
/**
 * Identifies if value is falsy string.
 * undefined, null, NaN, false, '' are considered as false value.
 * @param val
 */
export declare function isFalsyString(val: unknown): val is undefined | null;
/**
 * Identifies if value is truthy string.
 * @param val
 */
export declare function isTruthyString(val: Maybe<string | false>): val is string;
type Fn<A extends any[], R> = (...args: A) => R;
/**
 * Resolves if first argument is function with other arguments as argument to
 * user supplied function.
 * @param variable either a function to resolive or any value
 * @param args arguments for user supplied function
 * @returns value resolved from user supplied function
 */
export declare function resolve<A extends any[], R>(variable: Fn<A, R>, ...args: Parameters<Fn<A, R>>): ReturnType<Fn<A, R>>;
export declare function resolve<T>(variable: T): T;
export {};
