import { Maybe } from './declarations';
import { OptionKey, KeySelector } from './transform';
/**
 * Identify if two list are the same
 *
 * @param list1
 * @param list2
 *
 * @remarks
 * The function assumes that the elements aren't mutated
 */
export declare function isListEqual(list1: unknown[], list2: unknown[]): boolean;
/**
 * Get a random item from the list
 *
 * @param items
 */
export declare function getRandomFromList<T>(items: T[]): T | undefined;
/**
 * Get an element around certain index in a list
 *
 * @param list
 * @param index
 */
export declare function getElementAround<T>(list: T[], index: number): T | undefined;
/**
 * Get a defined element around certain index in a list
 *
 * @param list
 * @param index
 */
export declare function getDefinedElementAround<T>(list: Maybe<T>[], currentIndex: number): Maybe<T>;
/**
 * Get a duplicate count for each element in a list
 *
 * @param list
 * @param keySelector get key from an element
 *
 * @returns map of element key and duplicate count
 *
 * @remarks
 * The map only includes element for which there is a duplicate
 */
export declare function getDuplicates<T, K extends OptionKey>(list: T[], keySelector: KeySelector<T, K>): string[];
export declare function getDuplicates<T, K extends OptionKey>(list: Maybe<T[]>, keySelector: KeySelector<T, K>): string[] | undefined;
/**
 * Find difference between two list
 *
 * @param listA
 * @param listB
 * @param keySelector get key from an element
 *
 * @returns list of added, modified, removed and unmodified elements
 */
export declare function findDifferenceInList<T, K extends OptionKey>(listA: T[], listB: T[], keySelector: KeySelector<T, K>): {
    added: T[];
    modified: {
        old: T;
        new: T;
    }[];
    removed: T[];
    unmodified: T[];
};
/**
 * Find unique items from a list
 *
 * @param list
 * @param getItemHash method to get id to check uniqueness
 *
 * @remarks
 * If getItemHash is not supplied, comparision is done by casting items in list
 * to string
 */
export declare function unique<T>(list: undefined | null, getItemHash?: ((item: T) => string | number)): undefined;
export declare function unique<T>(list: T[], getItemHash?: ((item: T) => string | number)): T[];
export declare function max<T>(list: Maybe<T[]>, getNumericValue: (val: T) => number | null | undefined): T | undefined;
export declare function min<T>(list: Maybe<T[]>, getNumericValue: (val: T) => number | null | undefined): T | undefined;
