import { Obj, Maybe } from './declarations';
export type OptionKey = string | number;
type Modifier<T, Q, K extends OptionKey> = (element: T, key: K, index: number, acc: Partial<Record<K, Q>>) => Q;
type ListModifier<T, Q, K extends OptionKey> = (element: T, key: K, index: number, acc: Q[]) => Q;
type GroupItemModifier<T, Q, K extends OptionKey> = (element: T, key: K, index: number, acc: Partial<Record<K, Q[]>>) => Q;
type GroupListModifier<T, R> = (elements: T[], key: string) => R;
export type KeySelector<T, K extends OptionKey> = (element: T, index: number) => K;
type NewKeySelector<T, K extends OptionKey> = (key: string, element: T) => K;
/**
 * Transform list to object
 * @param list
 * @param keySelector get key from item in list
 * @param modifier get new value from item in list
 */
export declare function listToMap<T, K extends OptionKey>(list: T[], keySelector: KeySelector<T, K>): Record<K, T>;
export declare function listToMap<T, K extends OptionKey>(list: Maybe<T[]>, keySelector: KeySelector<T, K>): Record<K, T> | undefined;
export declare function listToMap<T, Q, K extends OptionKey>(list: T[], keySelector: KeySelector<T, K>, modifier: Modifier<T, Q, K>): Record<K, Q>;
export declare function listToMap<T, Q, K extends OptionKey>(list: Maybe<T[]>, keySelector: KeySelector<T, K>, modifier: Modifier<T, Q, K>): Record<K, Q> | undefined;
/**
 * Transform object to list
 * @param obj
 * @param modifier get new value from item in object
 */
export declare function mapToList<T>(obj: Obj<T>): T[];
export declare function mapToList<T>(obj: Maybe<Obj<T>>): T[] | undefined;
export declare function mapToList<T, Q>(obj: Obj<T>, modifier: ListModifier<T, Q, string>): Q[];
export declare function mapToList<T, Q>(obj: Maybe<Obj<T>>, modifier: ListModifier<T, Q, string>): Q[] | undefined;
/**
 * Transform object to object
 * @param obj
 * @param keySelector get new key for item in object
 * @param modifier get new value for item in object
 */
export declare function mapToMap<T, K extends OptionKey>(obj: Obj<T>, keySelector?: NewKeySelector<T, K>): Record<K, T>;
export declare function mapToMap<T, K extends OptionKey>(obj: Maybe<Obj<T>>, keySelector?: NewKeySelector<T, K>): Record<K, T> | undefined;
export declare function mapToMap<T, Q, K extends OptionKey>(obj: Obj<T>, keySelector: NewKeySelector<T, K> | undefined, modifier: Modifier<T, Q, string>): Record<K, Q>;
export declare function mapToMap<T, Q, K extends OptionKey>(obj: Maybe<Obj<T>>, keySelector: NewKeySelector<T, K> | undefined, modifier: Modifier<T, Q, string>): Record<K, Q> | undefined;
/**
 * Group list into object of list.
 * Items in list are grouped by key returned by keySelector
 * @param list
 * @param keySelector get key for item in list
 * @param modifier get new value for item in list
 */
export declare function listToGroupList<T, K extends OptionKey>(list: T[], keySelector: KeySelector<T, K>): Obj<T[]>;
export declare function listToGroupList<T, K extends OptionKey>(list: Maybe<T[]>, keySelector: KeySelector<T, K>): Obj<T[]> | undefined;
export declare function listToGroupList<T, Q, K extends OptionKey>(list: T[], keySelector: KeySelector<T, K>, modifier: GroupItemModifier<T, Q, K>): Obj<Q[]>;
export declare function listToGroupList<T, Q, K extends OptionKey>(list: Maybe<T[]>, keySelector: KeySelector<T, K>, modifier: GroupItemModifier<T, Q, K>): Obj<Q[]> | undefined;
export declare function listToGroupList<T, Q, K extends OptionKey, R>(list: T[], keySelector: KeySelector<T, K>, modifier: GroupItemModifier<T, Q, K>, groupModifier: GroupListModifier<Q, R>): Obj<R>;
export declare function listToGroupList<T, Q, K extends OptionKey, R>(list: Maybe<T[]>, keySelector: KeySelector<T, K>, modifier: GroupItemModifier<T, Q, K>, groupModifier: GroupListModifier<Q, R>): Obj<R> | undefined;
export declare function listToGroupList<T, K extends OptionKey, R>(list: T[], keySelector: KeySelector<T, K>, modifier: undefined, groupModifier: GroupListModifier<T, R>): Obj<R>;
export declare function listToGroupList<T, K extends OptionKey, R>(list: Maybe<T[]>, keySelector: KeySelector<T, K>, modifier: undefined, groupModifier: GroupListModifier<T, R>): Obj<R> | undefined;
export {};
